@@ -1,13 +1,14 @@
 package ElasticSearch::Transport;
 {
-  $ElasticSearch::Transport::VERSION = '0.43';
+  $ElasticSearch::Transport::VERSION = '0.44';
 }
 
 use strict;
 use warnings FATAL => 'all';
-use ElasticSearch::Util qw(throw parse_params);
+use ElasticSearch::Util qw(throw build_error parse_params);
 use URI();
 use JSON();
+use Encode qw(decode_utf8);
 use Scalar::Util qw(openhandle);
 
 our %Transport = (
@@ -17,7 +18,7 @@ our %Transport = (
     'httptiny' => 'ElasticSearch::Transport::HTTPTiny',
     'curl'     => 'ElasticSearch::Transport::Curl',
     'aehttp'   => 'ElasticSearch::Transport::AEHTTP',
-    'aecurl'     => 'ElasticSearch::Transport::AECurl',
+    'aecurl'   => 'ElasticSearch::Transport::AECurl',
 );
 
 #===================================
@@ -49,7 +50,7 @@ sub new {
     $self->{_default_servers}
         = [ ref $servers eq 'ARRAY' ? @$servers : $servers ];
 
-    for (qw(timeout max_requests no_refresh)) {
+    for (qw(timeout max_requests no_refresh deflate)) {
         next unless exists $params->{$_};
         $self->$_( delete $params->{$_} );
     }
@@ -325,6 +326,21 @@ sub http_uri {
     return $uri->as_string;
 }
 
+#===================================
+sub inflate {
+#===================================
+    my $self = shift;
+    my $content = shift;
+    my $output;
+        require IO::Uncompress::Inflate;
+
+        no warnings 'once';
+        IO::Uncompress::Inflate::inflate( \$content, \$output, Transparent => 0 )
+            or die "Couldn't inflate response: "
+                . $IO::Uncompress::Inflate::InflateError;
+    return $output;
+}
+
 #===================================
 sub timeout {
 #===================================
@@ -336,6 +352,17 @@ sub timeout {
     return $self->{_timeout} || 0;
 }
 
+#===================================
+sub deflate {
+#===================================
+    my $self = shift;
+    if (@_) {
+        $self->{_deflate} = shift;
+        $self->clear_clients;
+    }
+    return $self->{_deflate} || 0;
+}
+
 #===================================
 sub no_refresh {
 #===================================
@@ -596,6 +623,7 @@ happens via the main L<ElasticSearch> class.
         transport   => 'httplite',
         timeout     => '10',
         no_refresh  => 0 | 1,
+        delate      => 0 | 1,
     );
 
     my $t = $e->transport;
@@ -616,6 +644,9 @@ happens via the main L<ElasticSearch> class.
     $t->no_refresh(0|1)             # don't retrieve the live node list
                                     # instead, use just the nodes specified
 
+    $t->deflate(0|1);               # should ES deflate its responses
+                                    # useful if ES is on a remote network
+
     $t->register('foo',$class)      # register new Transport backend
 
 =head1 WHICH TRANSPORT SHOULD YOU USE
