@@ -1,6 +1,6 @@
 package ElasticSearch::Transport::HTTPTiny;
 {
-  $ElasticSearch::Transport::HTTPTiny::VERSION = '0.43';
+  $ElasticSearch::Transport::HTTPTiny::VERSION = '0.44';
 }
 
 use strict;
@@ -45,7 +45,11 @@ sub send_request {
 
     my $code    = $response->{status};
     my $msg     = $response->{reason};
-    my $content = decode_utf8( $response->{content} || '' );
+    my $content = $response->{content} || '';
+
+    my $ce = $response->{headers}{'content-encoding'} || '';
+    $content = $self->inflate($content) if $ce eq 'deflate';
+    $content = decode_utf8 $content;
 
     return $content if $code && $code >= 200 && $code <= 209;
 
@@ -79,7 +83,10 @@ sub client {
 #===================================
     my $self = shift;
     unless ( $self->{_client}{$$} ) {
-        my $client = HTTP::Tiny->new( timeout => $self->timeout || 10000 );
+        my %params = ( timeout => $self->timeout || 10000 );
+        $params{default_headers} = { 'Accept-Encoding' => 'deflate' }
+            if $self->deflate;
+        my $client = HTTP::Tiny->new(%params);
         $self->{_client}{$$} = $client;
     }
     return $self->{_client}{$$};
